"""
RCABench API

RCABench - A comprehensive root cause analysis benchmarking platform for microservices

The version of the OpenAPI document: 1.1.51
Contact: team@rcabench.com
Generated by OpenAPI Generator (https://rcabench.openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from typing import Annotated, Any

from pydantic import Field, StrictFloat, StrictInt, StrictStr, validate_call

from rcabench.openapi.api_client import ApiClient, RequestSerialized
from rcabench.openapi.api_response import ApiResponse
from rcabench.openapi.models.execution_state import ExecutionState
from rcabench.openapi.models.generic_response_array_label_item import GenericResponseArrayLabelItem
from rcabench.openapi.models.generic_response_execution_detail_resp import GenericResponseExecutionDetailResp
from rcabench.openapi.models.generic_response_list_execution_resp import GenericResponseListExecutionResp
from rcabench.openapi.models.generic_response_submit_execution_resp import GenericResponseSubmitExecutionResp
from rcabench.openapi.models.generic_response_upload_execution_result_resp import (
    GenericResponseUploadExecutionResultResp,
)
from rcabench.openapi.models.status_type import StatusType
from rcabench.openapi.models.submit_execution_req import SubmitExecutionReq
from rcabench.openapi.models.upload_detector_result_req import UploadDetectorResultReq
from rcabench.openapi.models.upload_granularity_result_req import UploadGranularityResultReq
from rcabench.openapi.rest import RESTResponse, RESTResponseType


class ExecutionsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://rcabench.openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_call
    def get_execution_by_id(
        self,
        id: Annotated[StrictInt, Field(description="Execution ID")],
        _request_timeout: None
        | Annotated[StrictFloat, Field(gt=0)]
        | tuple[Annotated[StrictStr, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]] = None,
        _request_auth: dict[StrictStr, Any] | None = None,
        _content_type: StrictStr | None = None,
        _headers: dict[StrictStr, Any] | None = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> GenericResponseExecutionDetailResp:
        """Get execution by ID

        Get detailed information about a specific execution

        :param id: Execution ID (required)
        :type id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._get_execution_by_id_serialize(
            id=id, _request_auth=_request_auth, _content_type=_content_type, _headers=_headers, _host_index=_host_index
        )

        _response_types_map: dict[str, str | None] = {
            "200": "GenericResponseExecutionDetailResp",
            "400": "GenericResponseAny",
            "401": "GenericResponseAny",
            "403": "GenericResponseAny",
            "404": "GenericResponseAny",
            "500": "GenericResponseAny",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)

        assert response_data is not None and isinstance(response_data, RESTResponse), (
            "Response data must be of type RESTResponse"
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data  # type: ignore

    @validate_call
    def get_execution_by_id_with_http_info(
        self,
        id: Annotated[StrictInt, Field(description="Execution ID")],
        _request_timeout: None
        | Annotated[StrictFloat, Field(gt=0)]
        | tuple[Annotated[StrictStr, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]] = None,
        _request_auth: dict[StrictStr, Any] | None = None,
        _content_type: StrictStr | None = None,
        _headers: dict[StrictStr, Any] | None = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[GenericResponseExecutionDetailResp]:
        """Get execution by ID

        Get detailed information about a specific execution

        :param id: Execution ID (required)
        :type id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._get_execution_by_id_serialize(
            id=id, _request_auth=_request_auth, _content_type=_content_type, _headers=_headers, _host_index=_host_index
        )

        _response_types_map: dict[str, str | None] = {
            "200": "GenericResponseExecutionDetailResp",
            "400": "GenericResponseAny",
            "401": "GenericResponseAny",
            "403": "GenericResponseAny",
            "404": "GenericResponseAny",
            "500": "GenericResponseAny",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)

        assert response_data is not None and isinstance(response_data, RESTResponse), (
            "Response data must be of type RESTResponse"
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )  # type: ignore

    @validate_call
    def get_execution_by_id_without_preload_content(
        self,
        id: Annotated[StrictInt, Field(description="Execution ID")],
        _request_timeout: None
        | Annotated[StrictFloat, Field(gt=0)]
        | tuple[Annotated[StrictStr, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]] = None,
        _request_auth: dict[StrictStr, Any] | None = None,
        _content_type: StrictStr | None = None,
        _headers: dict[StrictStr, Any] | None = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get execution by ID

        Get detailed information about a specific execution

        :param id: Execution ID (required)
        :type id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._get_execution_by_id_serialize(
            id=id, _request_auth=_request_auth, _content_type=_content_type, _headers=_headers, _host_index=_host_index
        )

        _response_types_map: dict[str, str | None] = {
            "200": "GenericResponseExecutionDetailResp",
            "400": "GenericResponseAny",
            "401": "GenericResponseAny",
            "403": "GenericResponseAny",
            "404": "GenericResponseAny",
            "500": "GenericResponseAny",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)

        assert response_data is not None and isinstance(response_data, RESTResponse), (
            "Response data must be of type RESTResponse"
        )
        return response_data.response

    def _get_execution_by_id_serialize(
        self,
        id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:
        _host = None

        _collection_formats: dict[str, str] = {}

        _path_params: dict[str, str] = {}
        _query_params: list[tuple[str, str]] = []
        _header_params: dict[str, str | None] = _headers or {}
        _form_params: list[tuple[str, str]] = []
        _files: dict[str, str | bytes | list[str] | list[bytes] | list[tuple[str, bytes]]] = {}
        _body_params: bytes | None = None

        # process the path parameters
        if id is not None:
            _path_params["id"] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(["application/json"])

        # authentication setting
        _auth_settings: list[str] = ["BearerAuth"]

        return self.api_client.param_serialize(
            method="GET",
            resource_path="/api/v2/executions/{id}",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    def list_execution_labels(
        self,
        _request_timeout: None
        | Annotated[StrictFloat, Field(gt=0)]
        | tuple[Annotated[StrictStr, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]] = None,
        _request_auth: dict[StrictStr, Any] | None = None,
        _content_type: StrictStr | None = None,
        _headers: dict[StrictStr, Any] | None = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> GenericResponseArrayLabelItem:
        """List execution labels

        List all available label keys for executions

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._list_execution_labels_serialize(
            _request_auth=_request_auth, _content_type=_content_type, _headers=_headers, _host_index=_host_index
        )

        _response_types_map: dict[str, str | None] = {
            "200": "GenericResponseArrayLabelItem",
            "401": "GenericResponseAny",
            "403": "GenericResponseAny",
            "500": "GenericResponseAny",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)

        assert response_data is not None and isinstance(response_data, RESTResponse), (
            "Response data must be of type RESTResponse"
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data  # type: ignore

    @validate_call
    def list_execution_labels_with_http_info(
        self,
        _request_timeout: None
        | Annotated[StrictFloat, Field(gt=0)]
        | tuple[Annotated[StrictStr, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]] = None,
        _request_auth: dict[StrictStr, Any] | None = None,
        _content_type: StrictStr | None = None,
        _headers: dict[StrictStr, Any] | None = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[GenericResponseArrayLabelItem]:
        """List execution labels

        List all available label keys for executions

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._list_execution_labels_serialize(
            _request_auth=_request_auth, _content_type=_content_type, _headers=_headers, _host_index=_host_index
        )

        _response_types_map: dict[str, str | None] = {
            "200": "GenericResponseArrayLabelItem",
            "401": "GenericResponseAny",
            "403": "GenericResponseAny",
            "500": "GenericResponseAny",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)

        assert response_data is not None and isinstance(response_data, RESTResponse), (
            "Response data must be of type RESTResponse"
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )  # type: ignore

    @validate_call
    def list_execution_labels_without_preload_content(
        self,
        _request_timeout: None
        | Annotated[StrictFloat, Field(gt=0)]
        | tuple[Annotated[StrictStr, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]] = None,
        _request_auth: dict[StrictStr, Any] | None = None,
        _content_type: StrictStr | None = None,
        _headers: dict[StrictStr, Any] | None = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """List execution labels

        List all available label keys for executions

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._list_execution_labels_serialize(
            _request_auth=_request_auth, _content_type=_content_type, _headers=_headers, _host_index=_host_index
        )

        _response_types_map: dict[str, str | None] = {
            "200": "GenericResponseArrayLabelItem",
            "401": "GenericResponseAny",
            "403": "GenericResponseAny",
            "500": "GenericResponseAny",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)

        assert response_data is not None and isinstance(response_data, RESTResponse), (
            "Response data must be of type RESTResponse"
        )
        return response_data.response

    def _list_execution_labels_serialize(
        self,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:
        _host = None

        _collection_formats: dict[str, str] = {}

        _path_params: dict[str, str] = {}
        _query_params: list[tuple[str, str]] = []
        _header_params: dict[str, str | None] = _headers or {}
        _form_params: list[tuple[str, str]] = []
        _files: dict[str, str | bytes | list[str] | list[bytes] | list[tuple[str, bytes]]] = {}
        _body_params: bytes | None = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(["application/json"])

        # authentication setting
        _auth_settings: list[str] = ["BearerAuth"]

        return self.api_client.param_serialize(
            method="GET",
            resource_path="/api/v2/executions/labels",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    def list_executions(
        self,
        page: Annotated[StrictInt | None, Field(description="Page number")] = None,
        size: Annotated[StrictInt | None, Field(description="Page size")] = None,
        state: Annotated[ExecutionState | None, Field(description="Filter by execution state")] = None,
        status: Annotated[StatusType | None, Field(description="Filter by status")] = None,
        labels: Annotated[
            list[StrictStr] | None,
            Field(description="Filter by labels (array of key:value strings, e.g., 'type:test')"),
        ] = None,
        _request_timeout: None
        | Annotated[StrictFloat, Field(gt=0)]
        | tuple[Annotated[StrictStr, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]] = None,
        _request_auth: dict[StrictStr, Any] | None = None,
        _content_type: StrictStr | None = None,
        _headers: dict[StrictStr, Any] | None = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> GenericResponseListExecutionResp:
        """List executions

        Get a paginated list of executions with pagination and filtering

        :param page: Page number
        :type page: int
        :param size: Page size
        :type size: int
        :param state: Filter by execution state
        :type state: ExecutionState
        :param status: Filter by status
        :type status: StatusType
        :param labels: Filter by labels (array of key:value strings, e.g., 'type:test')
        :type labels: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._list_executions_serialize(
            page=page,
            size=size,
            state=state,
            status=status,
            labels=labels,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: dict[str, str | None] = {
            "200": "GenericResponseListExecutionResp",
            "400": "GenericResponseAny",
            "401": "GenericResponseAny",
            "403": "GenericResponseAny",
            "500": "GenericResponseAny",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)

        assert response_data is not None and isinstance(response_data, RESTResponse), (
            "Response data must be of type RESTResponse"
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data  # type: ignore

    @validate_call
    def list_executions_with_http_info(
        self,
        page: Annotated[StrictInt | None, Field(description="Page number")] = None,
        size: Annotated[StrictInt | None, Field(description="Page size")] = None,
        state: Annotated[ExecutionState | None, Field(description="Filter by execution state")] = None,
        status: Annotated[StatusType | None, Field(description="Filter by status")] = None,
        labels: Annotated[
            list[StrictStr] | None,
            Field(description="Filter by labels (array of key:value strings, e.g., 'type:test')"),
        ] = None,
        _request_timeout: None
        | Annotated[StrictFloat, Field(gt=0)]
        | tuple[Annotated[StrictStr, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]] = None,
        _request_auth: dict[StrictStr, Any] | None = None,
        _content_type: StrictStr | None = None,
        _headers: dict[StrictStr, Any] | None = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[GenericResponseListExecutionResp]:
        """List executions

        Get a paginated list of executions with pagination and filtering

        :param page: Page number
        :type page: int
        :param size: Page size
        :type size: int
        :param state: Filter by execution state
        :type state: ExecutionState
        :param status: Filter by status
        :type status: StatusType
        :param labels: Filter by labels (array of key:value strings, e.g., 'type:test')
        :type labels: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._list_executions_serialize(
            page=page,
            size=size,
            state=state,
            status=status,
            labels=labels,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: dict[str, str | None] = {
            "200": "GenericResponseListExecutionResp",
            "400": "GenericResponseAny",
            "401": "GenericResponseAny",
            "403": "GenericResponseAny",
            "500": "GenericResponseAny",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)

        assert response_data is not None and isinstance(response_data, RESTResponse), (
            "Response data must be of type RESTResponse"
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )  # type: ignore

    @validate_call
    def list_executions_without_preload_content(
        self,
        page: Annotated[StrictInt | None, Field(description="Page number")] = None,
        size: Annotated[StrictInt | None, Field(description="Page size")] = None,
        state: Annotated[ExecutionState | None, Field(description="Filter by execution state")] = None,
        status: Annotated[StatusType | None, Field(description="Filter by status")] = None,
        labels: Annotated[
            list[StrictStr] | None,
            Field(description="Filter by labels (array of key:value strings, e.g., 'type:test')"),
        ] = None,
        _request_timeout: None
        | Annotated[StrictFloat, Field(gt=0)]
        | tuple[Annotated[StrictStr, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]] = None,
        _request_auth: dict[StrictStr, Any] | None = None,
        _content_type: StrictStr | None = None,
        _headers: dict[StrictStr, Any] | None = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """List executions

        Get a paginated list of executions with pagination and filtering

        :param page: Page number
        :type page: int
        :param size: Page size
        :type size: int
        :param state: Filter by execution state
        :type state: ExecutionState
        :param status: Filter by status
        :type status: StatusType
        :param labels: Filter by labels (array of key:value strings, e.g., 'type:test')
        :type labels: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._list_executions_serialize(
            page=page,
            size=size,
            state=state,
            status=status,
            labels=labels,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: dict[str, str | None] = {
            "200": "GenericResponseListExecutionResp",
            "400": "GenericResponseAny",
            "401": "GenericResponseAny",
            "403": "GenericResponseAny",
            "500": "GenericResponseAny",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)

        assert response_data is not None and isinstance(response_data, RESTResponse), (
            "Response data must be of type RESTResponse"
        )
        return response_data.response

    def _list_executions_serialize(
        self,
        page,
        size,
        state,
        status,
        labels,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:
        _host = None

        _collection_formats: dict[str, str] = {
            "labels": "csv",
        }

        _path_params: dict[str, str] = {}
        _query_params: list[tuple[str, str]] = []
        _header_params: dict[str, str | None] = _headers or {}
        _form_params: list[tuple[str, str]] = []
        _files: dict[str, str | bytes | list[str] | list[bytes] | list[tuple[str, bytes]]] = {}
        _body_params: bytes | None = None

        # process the path parameters
        # process the query parameters
        if page is not None:
            _query_params.append(("page", page))

        if size is not None:
            _query_params.append(("size", size))

        if state is not None:
            _query_params.append(("state", state.value))

        if status is not None:
            _query_params.append(("status", status.value))

        if labels is not None:
            _query_params.append(("labels", labels))

        # process the header parameters
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(["application/json"])

        # authentication setting
        _auth_settings: list[str] = ["BearerAuth"]

        return self.api_client.param_serialize(
            method="GET",
            resource_path="/api/v2/executions",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    def run_algorithm(
        self,
        request: Annotated[SubmitExecutionReq, Field(description="Algorithm execution request")],
        _request_timeout: None
        | Annotated[StrictFloat, Field(gt=0)]
        | tuple[Annotated[StrictStr, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]] = None,
        _request_auth: dict[StrictStr, Any] | None = None,
        _content_type: StrictStr | None = None,
        _headers: dict[StrictStr, Any] | None = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> GenericResponseSubmitExecutionResp:
        """Submit batch algorithm execution

        Submit multiple algorithm execution tasks in batch. Supports mixing datapack (v1 compatible) and dataset (v2 feature) executions.

        :param request: Algorithm execution request (required)
        :type request: SubmitExecutionReq
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._run_algorithm_serialize(
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: dict[str, str | None] = {
            "200": "GenericResponseSubmitExecutionResp",
            "400": "GenericResponseAny",
            "401": "GenericResponseAny",
            "403": "GenericResponseAny",
            "404": "GenericResponseAny",
            "500": "GenericResponseAny",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)

        assert response_data is not None and isinstance(response_data, RESTResponse), (
            "Response data must be of type RESTResponse"
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data  # type: ignore

    @validate_call
    def run_algorithm_with_http_info(
        self,
        request: Annotated[SubmitExecutionReq, Field(description="Algorithm execution request")],
        _request_timeout: None
        | Annotated[StrictFloat, Field(gt=0)]
        | tuple[Annotated[StrictStr, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]] = None,
        _request_auth: dict[StrictStr, Any] | None = None,
        _content_type: StrictStr | None = None,
        _headers: dict[StrictStr, Any] | None = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[GenericResponseSubmitExecutionResp]:
        """Submit batch algorithm execution

        Submit multiple algorithm execution tasks in batch. Supports mixing datapack (v1 compatible) and dataset (v2 feature) executions.

        :param request: Algorithm execution request (required)
        :type request: SubmitExecutionReq
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._run_algorithm_serialize(
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: dict[str, str | None] = {
            "200": "GenericResponseSubmitExecutionResp",
            "400": "GenericResponseAny",
            "401": "GenericResponseAny",
            "403": "GenericResponseAny",
            "404": "GenericResponseAny",
            "500": "GenericResponseAny",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)

        assert response_data is not None and isinstance(response_data, RESTResponse), (
            "Response data must be of type RESTResponse"
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )  # type: ignore

    @validate_call
    def run_algorithm_without_preload_content(
        self,
        request: Annotated[SubmitExecutionReq, Field(description="Algorithm execution request")],
        _request_timeout: None
        | Annotated[StrictFloat, Field(gt=0)]
        | tuple[Annotated[StrictStr, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]] = None,
        _request_auth: dict[StrictStr, Any] | None = None,
        _content_type: StrictStr | None = None,
        _headers: dict[StrictStr, Any] | None = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Submit batch algorithm execution

        Submit multiple algorithm execution tasks in batch. Supports mixing datapack (v1 compatible) and dataset (v2 feature) executions.

        :param request: Algorithm execution request (required)
        :type request: SubmitExecutionReq
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._run_algorithm_serialize(
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: dict[str, str | None] = {
            "200": "GenericResponseSubmitExecutionResp",
            "400": "GenericResponseAny",
            "401": "GenericResponseAny",
            "403": "GenericResponseAny",
            "404": "GenericResponseAny",
            "500": "GenericResponseAny",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)

        assert response_data is not None and isinstance(response_data, RESTResponse), (
            "Response data must be of type RESTResponse"
        )
        return response_data.response

    def _run_algorithm_serialize(
        self,
        request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:
        _host = None

        _collection_formats: dict[str, str] = {}

        _path_params: dict[str, str] = {}
        _query_params: list[tuple[str, str]] = []
        _header_params: dict[str, str | None] = _headers or {}
        _form_params: list[tuple[str, str]] = []
        _files: dict[str, str | bytes | list[str] | list[bytes] | list[tuple[str, bytes]]] = {}
        _body_params: bytes | None = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if request is not None:
            _body_params = request

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(["application/json"])

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params["Content-Type"] = _content_type
        else:
            _default_content_type = self.api_client.select_header_content_type(["application/json"])
            if _default_content_type is not None:
                _header_params["Content-Type"] = _default_content_type

        # authentication setting
        _auth_settings: list[str] = ["BearerAuth"]

        return self.api_client.param_serialize(
            method="POST",
            resource_path="/api/v2/executions/execute",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    def upload_detection_results(
        self,
        execution_id: Annotated[StrictInt, Field(description="Execution ID")],
        request: Annotated[UploadDetectorResultReq, Field(description="Detector results")],
        _request_timeout: None
        | Annotated[StrictFloat, Field(gt=0)]
        | tuple[Annotated[StrictStr, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]] = None,
        _request_auth: dict[StrictStr, Any] | None = None,
        _content_type: StrictStr | None = None,
        _headers: dict[StrictStr, Any] | None = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> GenericResponseUploadExecutionResultResp:
        """Upload detector results

        Upload detection results for detector algorithm via API instead of file collection

        :param execution_id: Execution ID (required)
        :type execution_id: int
        :param request: Detector results (required)
        :type request: UploadDetectorResultReq
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._upload_detection_results_serialize(
            execution_id=execution_id,
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: dict[str, str | None] = {
            "200": "GenericResponseUploadExecutionResultResp",
            "400": "GenericResponseAny",
            "401": "GenericResponseAny",
            "403": "GenericResponseAny",
            "404": "GenericResponseAny",
            "500": "GenericResponseAny",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)

        assert response_data is not None and isinstance(response_data, RESTResponse), (
            "Response data must be of type RESTResponse"
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data  # type: ignore

    @validate_call
    def upload_detection_results_with_http_info(
        self,
        execution_id: Annotated[StrictInt, Field(description="Execution ID")],
        request: Annotated[UploadDetectorResultReq, Field(description="Detector results")],
        _request_timeout: None
        | Annotated[StrictFloat, Field(gt=0)]
        | tuple[Annotated[StrictStr, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]] = None,
        _request_auth: dict[StrictStr, Any] | None = None,
        _content_type: StrictStr | None = None,
        _headers: dict[StrictStr, Any] | None = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[GenericResponseUploadExecutionResultResp]:
        """Upload detector results

        Upload detection results for detector algorithm via API instead of file collection

        :param execution_id: Execution ID (required)
        :type execution_id: int
        :param request: Detector results (required)
        :type request: UploadDetectorResultReq
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._upload_detection_results_serialize(
            execution_id=execution_id,
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: dict[str, str | None] = {
            "200": "GenericResponseUploadExecutionResultResp",
            "400": "GenericResponseAny",
            "401": "GenericResponseAny",
            "403": "GenericResponseAny",
            "404": "GenericResponseAny",
            "500": "GenericResponseAny",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)

        assert response_data is not None and isinstance(response_data, RESTResponse), (
            "Response data must be of type RESTResponse"
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )  # type: ignore

    @validate_call
    def upload_detection_results_without_preload_content(
        self,
        execution_id: Annotated[StrictInt, Field(description="Execution ID")],
        request: Annotated[UploadDetectorResultReq, Field(description="Detector results")],
        _request_timeout: None
        | Annotated[StrictFloat, Field(gt=0)]
        | tuple[Annotated[StrictStr, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]] = None,
        _request_auth: dict[StrictStr, Any] | None = None,
        _content_type: StrictStr | None = None,
        _headers: dict[StrictStr, Any] | None = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Upload detector results

        Upload detection results for detector algorithm via API instead of file collection

        :param execution_id: Execution ID (required)
        :type execution_id: int
        :param request: Detector results (required)
        :type request: UploadDetectorResultReq
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._upload_detection_results_serialize(
            execution_id=execution_id,
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: dict[str, str | None] = {
            "200": "GenericResponseUploadExecutionResultResp",
            "400": "GenericResponseAny",
            "401": "GenericResponseAny",
            "403": "GenericResponseAny",
            "404": "GenericResponseAny",
            "500": "GenericResponseAny",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)

        assert response_data is not None and isinstance(response_data, RESTResponse), (
            "Response data must be of type RESTResponse"
        )
        return response_data.response

    def _upload_detection_results_serialize(
        self,
        execution_id,
        request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:
        _host = None

        _collection_formats: dict[str, str] = {}

        _path_params: dict[str, str] = {}
        _query_params: list[tuple[str, str]] = []
        _header_params: dict[str, str | None] = _headers or {}
        _form_params: list[tuple[str, str]] = []
        _files: dict[str, str | bytes | list[str] | list[bytes] | list[tuple[str, bytes]]] = {}
        _body_params: bytes | None = None

        # process the path parameters
        if execution_id is not None:
            _path_params["execution_id"] = execution_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if request is not None:
            _body_params = request

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(["application/json"])

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params["Content-Type"] = _content_type
        else:
            _default_content_type = self.api_client.select_header_content_type(["application/json"])
            if _default_content_type is not None:
                _header_params["Content-Type"] = _default_content_type

        # authentication setting
        _auth_settings: list[str] = ["BearerAuth"]

        return self.api_client.param_serialize(
            method="POST",
            resource_path="/api/v2/executions/{execution_id}/detector_results",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    def upload_localization_results(
        self,
        execution_id: Annotated[StrictInt, Field(description="Execution ID")],
        request: Annotated[UploadGranularityResultReq, Field(description="Granularity results")],
        _request_timeout: None
        | Annotated[StrictFloat, Field(gt=0)]
        | tuple[Annotated[StrictStr, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]] = None,
        _request_auth: dict[StrictStr, Any] | None = None,
        _content_type: StrictStr | None = None,
        _headers: dict[StrictStr, Any] | None = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> GenericResponseUploadExecutionResultResp:
        """Upload granularity results

        Upload granularity results for regular algorithms via API instead of file collection

        :param execution_id: Execution ID (required)
        :type execution_id: int
        :param request: Granularity results (required)
        :type request: UploadGranularityResultReq
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._upload_localization_results_serialize(
            execution_id=execution_id,
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: dict[str, str | None] = {
            "200": "GenericResponseUploadExecutionResultResp",
            "400": "GenericResponseAny",
            "401": "GenericResponseAny",
            "403": "GenericResponseAny",
            "404": "GenericResponseAny",
            "500": "GenericResponseAny",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)

        assert response_data is not None and isinstance(response_data, RESTResponse), (
            "Response data must be of type RESTResponse"
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data  # type: ignore

    @validate_call
    def upload_localization_results_with_http_info(
        self,
        execution_id: Annotated[StrictInt, Field(description="Execution ID")],
        request: Annotated[UploadGranularityResultReq, Field(description="Granularity results")],
        _request_timeout: None
        | Annotated[StrictFloat, Field(gt=0)]
        | tuple[Annotated[StrictStr, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]] = None,
        _request_auth: dict[StrictStr, Any] | None = None,
        _content_type: StrictStr | None = None,
        _headers: dict[StrictStr, Any] | None = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[GenericResponseUploadExecutionResultResp]:
        """Upload granularity results

        Upload granularity results for regular algorithms via API instead of file collection

        :param execution_id: Execution ID (required)
        :type execution_id: int
        :param request: Granularity results (required)
        :type request: UploadGranularityResultReq
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._upload_localization_results_serialize(
            execution_id=execution_id,
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: dict[str, str | None] = {
            "200": "GenericResponseUploadExecutionResultResp",
            "400": "GenericResponseAny",
            "401": "GenericResponseAny",
            "403": "GenericResponseAny",
            "404": "GenericResponseAny",
            "500": "GenericResponseAny",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)

        assert response_data is not None and isinstance(response_data, RESTResponse), (
            "Response data must be of type RESTResponse"
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )  # type: ignore

    @validate_call
    def upload_localization_results_without_preload_content(
        self,
        execution_id: Annotated[StrictInt, Field(description="Execution ID")],
        request: Annotated[UploadGranularityResultReq, Field(description="Granularity results")],
        _request_timeout: None
        | Annotated[StrictFloat, Field(gt=0)]
        | tuple[Annotated[StrictStr, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]] = None,
        _request_auth: dict[StrictStr, Any] | None = None,
        _content_type: StrictStr | None = None,
        _headers: dict[StrictStr, Any] | None = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Upload granularity results

        Upload granularity results for regular algorithms via API instead of file collection

        :param execution_id: Execution ID (required)
        :type execution_id: int
        :param request: Granularity results (required)
        :type request: UploadGranularityResultReq
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._upload_localization_results_serialize(
            execution_id=execution_id,
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: dict[str, str | None] = {
            "200": "GenericResponseUploadExecutionResultResp",
            "400": "GenericResponseAny",
            "401": "GenericResponseAny",
            "403": "GenericResponseAny",
            "404": "GenericResponseAny",
            "500": "GenericResponseAny",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)

        assert response_data is not None and isinstance(response_data, RESTResponse), (
            "Response data must be of type RESTResponse"
        )
        return response_data.response

    def _upload_localization_results_serialize(
        self,
        execution_id,
        request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:
        _host = None

        _collection_formats: dict[str, str] = {}

        _path_params: dict[str, str] = {}
        _query_params: list[tuple[str, str]] = []
        _header_params: dict[str, str | None] = _headers or {}
        _form_params: list[tuple[str, str]] = []
        _files: dict[str, str | bytes | list[str] | list[bytes] | list[tuple[str, bytes]]] = {}
        _body_params: bytes | None = None

        # process the path parameters
        if execution_id is not None:
            _path_params["execution_id"] = execution_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if request is not None:
            _body_params = request

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(["application/json"])

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params["Content-Type"] = _content_type
        else:
            _default_content_type = self.api_client.select_header_content_type(["application/json"])
            if _default_content_type is not None:
                _header_params["Content-Type"] = _default_content_type

        # authentication setting
        _auth_settings: list[str] = ["BearerAuth"]

        return self.api_client.param_serialize(
            method="POST",
            resource_path="/api/v2/executions/{execution_id}/granularity_results",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )



"""
RCABench API

RCABench - A comprehensive root cause analysis benchmarking platform for microservices

The version of the OpenAPI document: 1.1.51
Contact: team@rcabench.com
Generated by OpenAPI Generator (https://rcabench.openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
import pprint
from typing import Annotated, Any, ClassVar

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing_extensions import Self

from rcabench.openapi.models.chaos_node import ChaosNode
from rcabench.openapi.models.container_spec import ContainerSpec
from rcabench.openapi.models.label_item import LabelItem


class SubmitInjectionReq(BaseModel):
    """
    SubmitInjectionReq
    """  # noqa: E501

    algorithms: list[ContainerSpec] | None = Field(default=None, description="RCA algorithms to execute (optional)")
    benchmark: ContainerSpec = Field(description="Benchmark (detector) configuration")
    interval: Annotated[int, Field(strict=True, ge=1)] = Field(description="Total experiment interval in minutes")
    labels: list[LabelItem] | None = Field(default=None, description="Labels to attach to the injection")
    pedestal: ContainerSpec = Field(description="Pedestal (workload) configuration")
    pre_duration: Annotated[int, Field(strict=True, ge=1)] = Field(
        description="Normal data collection duration before fault injection"
    )
    project_name: StrictStr = Field(description="Project name")
    specs: list[list[ChaosNode]] = Field(
        description="Fault injection specs - 2D array where each sub-array is a batch of parallel faults"
    )
    additional_properties: dict[str, Any] = {}
    __properties: ClassVar[list[str]] = [
        "algorithms",
        "benchmark",
        "interval",
        "labels",
        "pedestal",
        "pre_duration",
        "project_name",
        "specs",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return self.model_dump_json(by_alias=True, exclude_unset=True)

    @classmethod
    def from_json(cls, json_str: str) -> Self | None:
        """Create an instance of SubmitInjectionReq from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * Fields in `self.additional_properties` are added to the output dict.
        """
        excluded_fields: set[str] = set(
            [
                "additional_properties",
            ]
        )

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in algorithms (list)
        _items = []
        if self.algorithms:
            for _item_algorithms in self.algorithms:
                if _item_algorithms:
                    _items.append(_item_algorithms.to_dict())
            _dict["algorithms"] = _items
        # override the default output from pydantic by calling `to_dict()` of benchmark
        if self.benchmark:
            _dict["benchmark"] = self.benchmark.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in labels (list)
        _items = []
        if self.labels:
            for _item_labels in self.labels:
                if _item_labels:
                    _items.append(_item_labels.to_dict())
            _dict["labels"] = _items
        # override the default output from pydantic by calling `to_dict()` of pedestal
        if self.pedestal:
            _dict["pedestal"] = self.pedestal.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in specs (list of list)
        _items = []
        if self.specs:
            for _item_specs in self.specs:
                if _item_specs:
                    _items.append([_inner_item.to_dict() for _inner_item in _item_specs if _inner_item is not None])
            _dict["specs"] = _items
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: dict[str, Any] | None) -> Self | None:
        """Create an instance of SubmitInjectionReq from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "algorithms": [ContainerSpec.from_dict(_item) for _item in obj["algorithms"]]
                if obj.get("algorithms") is not None
                else None,
                "benchmark": ContainerSpec.from_dict(obj["benchmark"]) if obj.get("benchmark") is not None else None,
                "interval": obj.get("interval"),
                "labels": [LabelItem.from_dict(_item) for _item in obj["labels"]]
                if obj.get("labels") is not None
                else None,
                "pedestal": ContainerSpec.from_dict(obj["pedestal"]) if obj.get("pedestal") is not None else None,
                "pre_duration": obj.get("pre_duration"),
                "project_name": obj.get("project_name"),
                "specs": [[ChaosNode.from_dict(_inner_item) for _inner_item in _item] for _item in obj["specs"]]
                if obj.get("specs") is not None
                else None,
            }
        )
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj



# coding: utf-8

# flake8: noqa

"""
RCABench API

RCABench - A comprehensive root cause analysis benchmarking platform for microservices

The version of the OpenAPI document: 1.1.51
Contact: team@rcabench.com
Generated by OpenAPI Generator (https://rcabench.openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

__version__ = "1.1.51"

# Define package exports
__all__ = [
    "AuthenticationApi",
    "ContainersApi",
    "DatasetsApi",
    "EvaluationsApi",
    "ExecutionsApi",
    "InjectionsApi",
    "ProjectsApi",
    "SystemApi",
    "TasksApi",
    "TracesApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "BatchEvaluateDatapackReq",
    "BatchEvaluateDatapackResp",
    "BatchEvaluateDatasetReq",
    "BatchEvaluateDatasetResp",
    "BatchManageInjectionLabelReq",
    "BatchManageInjectionLabelResp",
    "BuildOptions",
    "BuildingSpec",
    "ChaosChaosType",
    "ChaosGroundtruth",
    "ChaosNode",
    "ChaosPair",
    "ChaosResourceField",
    "ChaosResources",
    "ContainerDetailResp",
    "ContainerRef",
    "ContainerResp",
    "ContainerSpec",
    "ContainerType",
    "ContainerVersionDetailResp",
    "ContainerVersionResp",
    "CreateContainerReq",
    "CreateContainerVersionReq",
    "CreateDatasetReq",
    "CreateDatasetVersionReq",
    "CreateHelmConfigReq",
    "CreateParameterConfigReq",
    "CreateProjectReq",
    "DatapackState",
    "DatasetDetailResp",
    "DatasetRef",
    "DatasetResp",
    "DatasetVersionDetailResp",
    "DatasetVersionResp",
    "DateRange",
    "DetectorResultItem",
    "EvaluateDatapackItem",
    "EvaluateDatapackRef",
    "EvaluateDatapackSpec",
    "EvaluateDatasetItem",
    "EvaluateDatasetSpec",
    "ExecutionDetailResp",
    "ExecutionRef",
    "ExecutionResp",
    "ExecutionSpec",
    "ExecutionState",
    "GenericResponseAny",
    "GenericResponseArrayInjectionNoIssuesResp",
    "GenericResponseArrayInjectionWithIssuesResp",
    "GenericResponseArrayLabelItem",
    "GenericResponseBatchEvaluateDatapackResp",
    "GenericResponseBatchEvaluateDatasetResp",
    "GenericResponseBatchManageInjectionLabelResp",
    "GenericResponseContainerDetailResp",
    "GenericResponseContainerResp",
    "GenericResponseContainerVersionDetailResp",
    "GenericResponseContainerVersionResp",
    "GenericResponseDatasetDetailResp",
    "GenericResponseDatasetResp",
    "GenericResponseDatasetVersionDetailResp",
    "GenericResponseDatasetVersionResp",
    "GenericResponseExecutionDetailResp",
    "GenericResponseHealthCheckResp",
    "GenericResponseInjectionDetailResp",
    "GenericResponseInjectionMetadataResp",
    "GenericResponseInjectionResp",
    "GenericResponseListContainerResp",
    "GenericResponseListContainerVersionResp",
    "GenericResponseListDatasetDetailResp",
    "GenericResponseListDatasetResp",
    "GenericResponseListDatasetVersionResp",
    "GenericResponseListExecutionResp",
    "GenericResponseListInjectionResp",
    "GenericResponseListProjectResp",
    "GenericResponseListTaskResp",
    "GenericResponseLoginResp",
    "GenericResponseProjectDetailResp",
    "GenericResponseProjectResp",
    "GenericResponseSearchRespInjectionDetailResp",
    "GenericResponseSubmitContainerBuildResp",
    "GenericResponseSubmitDatapackBuildingResp",
    "GenericResponseSubmitExecutionResp",
    "GenericResponseSubmitInjectionResp",
    "GenericResponseTaskDetailResp",
    "GenericResponseUploadExecutionResultResp",
    "GenericResponseUserInfo",
    "GranularityResultItem",
    "HealthCheckResp",
    "HelmConfigDetailResp",
    "InjectionDetailResp",
    "InjectionLabelOperation",
    "InjectionMetadataResp",
    "InjectionNoIssuesResp",
    "InjectionResp",
    "InjectionWithIssuesResp",
    "LabelItem",
    "ListContainerResp",
    "ListContainerVersionResp",
    "ListDatasetDetailResp",
    "ListDatasetResp",
    "ListDatasetVersionResp",
    "ListExecutionResp",
    "ListInjectionResp",
    "ListProjectResp",
    "ListTaskResp",
    "LoginReq",
    "LoginResp",
    "ManageDatasetVersionInjectionReq",
    "ManageInjectionLabelReq",
    "PageSize",
    "PaginationInfo",
    "ParameterCategory",
    "ParameterSpec",
    "ParameterType",
    "ProjectDetailResp",
    "ProjectResp",
    "RegisterReq",
    "SearchDatasetReq",
    "SearchInjectionReq",
    "SearchRespInjectionDetailResp",
    "SortDirection",
    "SortOption",
    "StatusType",
    "SubmitBuildContainerReq",
    "SubmitBuildingItem",
    "SubmitContainerBuildResp",
    "SubmitDatapackBuildingReq",
    "SubmitDatapackBuildingResp",
    "SubmitExecutionItem",
    "SubmitExecutionReq",
    "SubmitExecutionResp",
    "SubmitInjectionItem",
    "SubmitInjectionReq",
    "SubmitInjectionResp",
    "TaskDetailResp",
    "TaskResp",
    "TaskState",
    "UploadDetectorResultReq",
    "UploadExecutionResultResp",
    "UploadGranularityResultReq",
    "UserInfo",
    "ValueDataType",
]

# import apis into sdk package
from rcabench.openapi.api.authentication_api import AuthenticationApi as AuthenticationApi
from rcabench.openapi.api.containers_api import ContainersApi as ContainersApi
from rcabench.openapi.api.datasets_api import DatasetsApi as DatasetsApi
from rcabench.openapi.api.evaluations_api import EvaluationsApi as EvaluationsApi
from rcabench.openapi.api.executions_api import ExecutionsApi as ExecutionsApi
from rcabench.openapi.api.injections_api import InjectionsApi as InjectionsApi
from rcabench.openapi.api.projects_api import ProjectsApi as ProjectsApi
from rcabench.openapi.api.system_api import SystemApi as SystemApi
from rcabench.openapi.api.tasks_api import TasksApi as TasksApi
from rcabench.openapi.api.traces_api import TracesApi as TracesApi

# import ApiClient
from rcabench.openapi.api_response import ApiResponse as ApiResponse
from rcabench.openapi.api_client import ApiClient as ApiClient
from rcabench.openapi.configuration import Configuration as Configuration
from rcabench.openapi.exceptions import OpenApiException as OpenApiException
from rcabench.openapi.exceptions import ApiTypeError as ApiTypeError
from rcabench.openapi.exceptions import ApiValueError as ApiValueError
from rcabench.openapi.exceptions import ApiKeyError as ApiKeyError
from rcabench.openapi.exceptions import ApiAttributeError as ApiAttributeError
from rcabench.openapi.exceptions import ApiException as ApiException

# import models into sdk package
from rcabench.openapi.models.batch_evaluate_datapack_req import BatchEvaluateDatapackReq as BatchEvaluateDatapackReq
from rcabench.openapi.models.batch_evaluate_datapack_resp import BatchEvaluateDatapackResp as BatchEvaluateDatapackResp
from rcabench.openapi.models.batch_evaluate_dataset_req import BatchEvaluateDatasetReq as BatchEvaluateDatasetReq
from rcabench.openapi.models.batch_evaluate_dataset_resp import BatchEvaluateDatasetResp as BatchEvaluateDatasetResp
from rcabench.openapi.models.batch_manage_injection_label_req import (
    BatchManageInjectionLabelReq as BatchManageInjectionLabelReq,
)
from rcabench.openapi.models.batch_manage_injection_label_resp import (
    BatchManageInjectionLabelResp as BatchManageInjectionLabelResp,
)
from rcabench.openapi.models.build_options import BuildOptions as BuildOptions
from rcabench.openapi.models.building_spec import BuildingSpec as BuildingSpec
from rcabench.openapi.models.chaos_chaos_type import ChaosChaosType as ChaosChaosType
from rcabench.openapi.models.chaos_groundtruth import ChaosGroundtruth as ChaosGroundtruth
from rcabench.openapi.models.chaos_node import ChaosNode as ChaosNode
from rcabench.openapi.models.chaos_pair import ChaosPair as ChaosPair
from rcabench.openapi.models.chaos_resource_field import ChaosResourceField as ChaosResourceField
from rcabench.openapi.models.chaos_resources import ChaosResources as ChaosResources
from rcabench.openapi.models.container_detail_resp import ContainerDetailResp as ContainerDetailResp
from rcabench.openapi.models.container_ref import ContainerRef as ContainerRef
from rcabench.openapi.models.container_resp import ContainerResp as ContainerResp
from rcabench.openapi.models.container_spec import ContainerSpec as ContainerSpec
from rcabench.openapi.models.container_type import ContainerType as ContainerType
from rcabench.openapi.models.container_version_detail_resp import (
    ContainerVersionDetailResp as ContainerVersionDetailResp,
)
from rcabench.openapi.models.container_version_resp import ContainerVersionResp as ContainerVersionResp
from rcabench.openapi.models.create_container_req import CreateContainerReq as CreateContainerReq
from rcabench.openapi.models.create_container_version_req import CreateContainerVersionReq as CreateContainerVersionReq
from rcabench.openapi.models.create_dataset_req import CreateDatasetReq as CreateDatasetReq
from rcabench.openapi.models.create_dataset_version_req import CreateDatasetVersionReq as CreateDatasetVersionReq
from rcabench.openapi.models.create_helm_config_req import CreateHelmConfigReq as CreateHelmConfigReq
from rcabench.openapi.models.create_parameter_config_req import CreateParameterConfigReq as CreateParameterConfigReq
from rcabench.openapi.models.create_project_req import CreateProjectReq as CreateProjectReq
from rcabench.openapi.models.datapack_state import DatapackState as DatapackState
from rcabench.openapi.models.dataset_detail_resp import DatasetDetailResp as DatasetDetailResp
from rcabench.openapi.models.dataset_ref import DatasetRef as DatasetRef
from rcabench.openapi.models.dataset_resp import DatasetResp as DatasetResp
from rcabench.openapi.models.dataset_version_detail_resp import DatasetVersionDetailResp as DatasetVersionDetailResp
from rcabench.openapi.models.dataset_version_resp import DatasetVersionResp as DatasetVersionResp
from rcabench.openapi.models.date_range import DateRange as DateRange
from rcabench.openapi.models.detector_result_item import DetectorResultItem as DetectorResultItem
from rcabench.openapi.models.evaluate_datapack_item import EvaluateDatapackItem as EvaluateDatapackItem
from rcabench.openapi.models.evaluate_datapack_ref import EvaluateDatapackRef as EvaluateDatapackRef
from rcabench.openapi.models.evaluate_datapack_spec import EvaluateDatapackSpec as EvaluateDatapackSpec
from rcabench.openapi.models.evaluate_dataset_item import EvaluateDatasetItem as EvaluateDatasetItem
from rcabench.openapi.models.evaluate_dataset_spec import EvaluateDatasetSpec as EvaluateDatasetSpec
from rcabench.openapi.models.execution_detail_resp import ExecutionDetailResp as ExecutionDetailResp
from rcabench.openapi.models.execution_ref import ExecutionRef as ExecutionRef
from rcabench.openapi.models.execution_resp import ExecutionResp as ExecutionResp
from rcabench.openapi.models.execution_spec import ExecutionSpec as ExecutionSpec
from rcabench.openapi.models.execution_state import ExecutionState as ExecutionState
from rcabench.openapi.models.generic_response_any import GenericResponseAny as GenericResponseAny
from rcabench.openapi.models.generic_response_array_injection_no_issues_resp import (
    GenericResponseArrayInjectionNoIssuesResp as GenericResponseArrayInjectionNoIssuesResp,
)
from rcabench.openapi.models.generic_response_array_injection_with_issues_resp import (
    GenericResponseArrayInjectionWithIssuesResp as GenericResponseArrayInjectionWithIssuesResp,
)
from rcabench.openapi.models.generic_response_array_label_item import (
    GenericResponseArrayLabelItem as GenericResponseArrayLabelItem,
)
from rcabench.openapi.models.generic_response_batch_evaluate_datapack_resp import (
    GenericResponseBatchEvaluateDatapackResp as GenericResponseBatchEvaluateDatapackResp,
)
from rcabench.openapi.models.generic_response_batch_evaluate_dataset_resp import (
    GenericResponseBatchEvaluateDatasetResp as GenericResponseBatchEvaluateDatasetResp,
)
from rcabench.openapi.models.generic_response_batch_manage_injection_label_resp import (
    GenericResponseBatchManageInjectionLabelResp as GenericResponseBatchManageInjectionLabelResp,
)
from rcabench.openapi.models.generic_response_container_detail_resp import (
    GenericResponseContainerDetailResp as GenericResponseContainerDetailResp,
)
from rcabench.openapi.models.generic_response_container_resp import (
    GenericResponseContainerResp as GenericResponseContainerResp,
)
from rcabench.openapi.models.generic_response_container_version_detail_resp import (
    GenericResponseContainerVersionDetailResp as GenericResponseContainerVersionDetailResp,
)
from rcabench.openapi.models.generic_response_container_version_resp import (
    GenericResponseContainerVersionResp as GenericResponseContainerVersionResp,
)
from rcabench.openapi.models.generic_response_dataset_detail_resp import (
    GenericResponseDatasetDetailResp as GenericResponseDatasetDetailResp,
)
from rcabench.openapi.models.generic_response_dataset_resp import (
    GenericResponseDatasetResp as GenericResponseDatasetResp,
)
from rcabench.openapi.models.generic_response_dataset_version_detail_resp import (
    GenericResponseDatasetVersionDetailResp as GenericResponseDatasetVersionDetailResp,
)
from rcabench.openapi.models.generic_response_dataset_version_resp import (
    GenericResponseDatasetVersionResp as GenericResponseDatasetVersionResp,
)
from rcabench.openapi.models.generic_response_execution_detail_resp import (
    GenericResponseExecutionDetailResp as GenericResponseExecutionDetailResp,
)
from rcabench.openapi.models.generic_response_health_check_resp import (
    GenericResponseHealthCheckResp as GenericResponseHealthCheckResp,
)
from rcabench.openapi.models.generic_response_injection_detail_resp import (
    GenericResponseInjectionDetailResp as GenericResponseInjectionDetailResp,
)
from rcabench.openapi.models.generic_response_injection_metadata_resp import (
    GenericResponseInjectionMetadataResp as GenericResponseInjectionMetadataResp,
)
from rcabench.openapi.models.generic_response_injection_resp import (
    GenericResponseInjectionResp as GenericResponseInjectionResp,
)
from rcabench.openapi.models.generic_response_list_container_resp import (
    GenericResponseListContainerResp as GenericResponseListContainerResp,
)
from rcabench.openapi.models.generic_response_list_container_version_resp import (
    GenericResponseListContainerVersionResp as GenericResponseListContainerVersionResp,
)
from rcabench.openapi.models.generic_response_list_dataset_detail_resp import (
    GenericResponseListDatasetDetailResp as GenericResponseListDatasetDetailResp,
)
from rcabench.openapi.models.generic_response_list_dataset_resp import (
    GenericResponseListDatasetResp as GenericResponseListDatasetResp,
)
from rcabench.openapi.models.generic_response_list_dataset_version_resp import (
    GenericResponseListDatasetVersionResp as GenericResponseListDatasetVersionResp,
)
from rcabench.openapi.models.generic_response_list_execution_resp import (
    GenericResponseListExecutionResp as GenericResponseListExecutionResp,
)
from rcabench.openapi.models.generic_response_list_injection_resp import (
    GenericResponseListInjectionResp as GenericResponseListInjectionResp,
)
from rcabench.openapi.models.generic_response_list_project_resp import (
    GenericResponseListProjectResp as GenericResponseListProjectResp,
)
from rcabench.openapi.models.generic_response_list_task_resp import (
    GenericResponseListTaskResp as GenericResponseListTaskResp,
)
from rcabench.openapi.models.generic_response_login_resp import GenericResponseLoginResp as GenericResponseLoginResp
from rcabench.openapi.models.generic_response_project_detail_resp import (
    GenericResponseProjectDetailResp as GenericResponseProjectDetailResp,
)
from rcabench.openapi.models.generic_response_project_resp import (
    GenericResponseProjectResp as GenericResponseProjectResp,
)
from rcabench.openapi.models.generic_response_search_resp_injection_detail_resp import (
    GenericResponseSearchRespInjectionDetailResp as GenericResponseSearchRespInjectionDetailResp,
)
from rcabench.openapi.models.generic_response_submit_container_build_resp import (
    GenericResponseSubmitContainerBuildResp as GenericResponseSubmitContainerBuildResp,
)
from rcabench.openapi.models.generic_response_submit_datapack_building_resp import (
    GenericResponseSubmitDatapackBuildingResp as GenericResponseSubmitDatapackBuildingResp,
)
from rcabench.openapi.models.generic_response_submit_execution_resp import (
    GenericResponseSubmitExecutionResp as GenericResponseSubmitExecutionResp,
)
from rcabench.openapi.models.generic_response_submit_injection_resp import (
    GenericResponseSubmitInjectionResp as GenericResponseSubmitInjectionResp,
)
from rcabench.openapi.models.generic_response_task_detail_resp import (
    GenericResponseTaskDetailResp as GenericResponseTaskDetailResp,
)
from rcabench.openapi.models.generic_response_upload_execution_result_resp import (
    GenericResponseUploadExecutionResultResp as GenericResponseUploadExecutionResultResp,
)
from rcabench.openapi.models.generic_response_user_info import GenericResponseUserInfo as GenericResponseUserInfo
from rcabench.openapi.models.granularity_result_item import GranularityResultItem as GranularityResultItem
from rcabench.openapi.models.health_check_resp import HealthCheckResp as HealthCheckResp
from rcabench.openapi.models.helm_config_detail_resp import HelmConfigDetailResp as HelmConfigDetailResp
from rcabench.openapi.models.injection_detail_resp import InjectionDetailResp as InjectionDetailResp
from rcabench.openapi.models.injection_label_operation import InjectionLabelOperation as InjectionLabelOperation
from rcabench.openapi.models.injection_metadata_resp import InjectionMetadataResp as InjectionMetadataResp
from rcabench.openapi.models.injection_no_issues_resp import InjectionNoIssuesResp as InjectionNoIssuesResp
from rcabench.openapi.models.injection_resp import InjectionResp as InjectionResp
from rcabench.openapi.models.injection_with_issues_resp import InjectionWithIssuesResp as InjectionWithIssuesResp
from rcabench.openapi.models.label_item import LabelItem as LabelItem
from rcabench.openapi.models.list_container_resp import ListContainerResp as ListContainerResp
from rcabench.openapi.models.list_container_version_resp import ListContainerVersionResp as ListContainerVersionResp
from rcabench.openapi.models.list_dataset_detail_resp import ListDatasetDetailResp as ListDatasetDetailResp
from rcabench.openapi.models.list_dataset_resp import ListDatasetResp as ListDatasetResp
from rcabench.openapi.models.list_dataset_version_resp import ListDatasetVersionResp as ListDatasetVersionResp
from rcabench.openapi.models.list_execution_resp import ListExecutionResp as ListExecutionResp
from rcabench.openapi.models.list_injection_resp import ListInjectionResp as ListInjectionResp
from rcabench.openapi.models.list_project_resp import ListProjectResp as ListProjectResp
from rcabench.openapi.models.list_task_resp import ListTaskResp as ListTaskResp
from rcabench.openapi.models.login_req import LoginReq as LoginReq
from rcabench.openapi.models.login_resp import LoginResp as LoginResp
from rcabench.openapi.models.manage_dataset_version_injection_req import (
    ManageDatasetVersionInjectionReq as ManageDatasetVersionInjectionReq,
)
from rcabench.openapi.models.manage_injection_label_req import ManageInjectionLabelReq as ManageInjectionLabelReq
from rcabench.openapi.models.page_size import PageSize as PageSize
from rcabench.openapi.models.pagination_info import PaginationInfo as PaginationInfo
from rcabench.openapi.models.parameter_category import ParameterCategory as ParameterCategory
from rcabench.openapi.models.parameter_spec import ParameterSpec as ParameterSpec
from rcabench.openapi.models.parameter_type import ParameterType as ParameterType
from rcabench.openapi.models.project_detail_resp import ProjectDetailResp as ProjectDetailResp
from rcabench.openapi.models.project_resp import ProjectResp as ProjectResp
from rcabench.openapi.models.register_req import RegisterReq as RegisterReq
from rcabench.openapi.models.search_dataset_req import SearchDatasetReq as SearchDatasetReq
from rcabench.openapi.models.search_injection_req import SearchInjectionReq as SearchInjectionReq
from rcabench.openapi.models.search_resp_injection_detail_resp import (
    SearchRespInjectionDetailResp as SearchRespInjectionDetailResp,
)
from rcabench.openapi.models.sort_direction import SortDirection as SortDirection
from rcabench.openapi.models.sort_option import SortOption as SortOption
from rcabench.openapi.models.status_type import StatusType as StatusType
from rcabench.openapi.models.submit_build_container_req import SubmitBuildContainerReq as SubmitBuildContainerReq
from rcabench.openapi.models.submit_building_item import SubmitBuildingItem as SubmitBuildingItem
from rcabench.openapi.models.submit_container_build_resp import SubmitContainerBuildResp as SubmitContainerBuildResp
from rcabench.openapi.models.submit_datapack_building_req import SubmitDatapackBuildingReq as SubmitDatapackBuildingReq
from rcabench.openapi.models.submit_datapack_building_resp import (
    SubmitDatapackBuildingResp as SubmitDatapackBuildingResp,
)
from rcabench.openapi.models.submit_execution_item import SubmitExecutionItem as SubmitExecutionItem
from rcabench.openapi.models.submit_execution_req import SubmitExecutionReq as SubmitExecutionReq
from rcabench.openapi.models.submit_execution_resp import SubmitExecutionResp as SubmitExecutionResp
from rcabench.openapi.models.submit_injection_item import SubmitInjectionItem as SubmitInjectionItem
from rcabench.openapi.models.submit_injection_req import SubmitInjectionReq as SubmitInjectionReq
from rcabench.openapi.models.submit_injection_resp import SubmitInjectionResp as SubmitInjectionResp
from rcabench.openapi.models.task_detail_resp import TaskDetailResp as TaskDetailResp
from rcabench.openapi.models.task_resp import TaskResp as TaskResp
from rcabench.openapi.models.task_state import TaskState as TaskState
from rcabench.openapi.models.upload_detector_result_req import UploadDetectorResultReq as UploadDetectorResultReq
from rcabench.openapi.models.upload_execution_result_resp import UploadExecutionResultResp as UploadExecutionResultResp
from rcabench.openapi.models.upload_granularity_result_req import (
    UploadGranularityResultReq as UploadGranularityResultReq,
)
from rcabench.openapi.models.user_info import UserInfo as UserInfo
from rcabench.openapi.models.value_data_type import ValueDataType as ValueDataType



"""
RCABench API

RCABench - A comprehensive root cause analysis benchmarking platform for microservices

The version of the OpenAPI document: 1.1.51
Contact: team@rcabench.com
Generated by OpenAPI Generator (https://rcabench.openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from typing import Annotated, Any

from pydantic import Field, StrictFloat, StrictInt, StrictStr, validate_call

from rcabench.openapi.api_client import ApiClient, RequestSerialized
from rcabench.openapi.api_response import ApiResponse
from rcabench.openapi.models.batch_evaluate_datapack_req import BatchEvaluateDatapackReq
from rcabench.openapi.models.batch_evaluate_dataset_req import BatchEvaluateDatasetReq
from rcabench.openapi.models.generic_response_batch_evaluate_datapack_resp import (
    GenericResponseBatchEvaluateDatapackResp,
)
from rcabench.openapi.models.generic_response_batch_evaluate_dataset_resp import GenericResponseBatchEvaluateDatasetResp
from rcabench.openapi.rest import RESTResponse, RESTResponseType


class EvaluationsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://rcabench.openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_call
    def evaluate_algorithm_on_datapacks(
        self,
        request: Annotated[
            BatchEvaluateDatapackReq,
            Field(description="Batch evaluation request containing multiple algorithm-datapack pairs"),
        ],
        _request_timeout: None
        | Annotated[StrictFloat, Field(gt=0)]
        | tuple[Annotated[StrictStr, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]] = None,
        _request_auth: dict[StrictStr, Any] | None = None,
        _content_type: StrictStr | None = None,
        _headers: dict[StrictStr, Any] | None = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> GenericResponseBatchEvaluateDatapackResp:
        """List Datapack Evaluation Results

        Retrieve evaluation data for multiple algorithm-datapack pairs.

        :param request: Batch evaluation request containing multiple algorithm-datapack pairs (required)
        :type request: BatchEvaluateDatapackReq
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._evaluate_algorithm_on_datapacks_serialize(
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: dict[str, str | None] = {
            "200": "GenericResponseBatchEvaluateDatapackResp",
            "400": "GenericResponseAny",
            "401": "GenericResponseAny",
            "403": "GenericResponseAny",
            "500": "GenericResponseAny",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)

        assert response_data is not None and isinstance(response_data, RESTResponse), (
            "Response data must be of type RESTResponse"
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data  # type: ignore

    @validate_call
    def evaluate_algorithm_on_datapacks_with_http_info(
        self,
        request: Annotated[
            BatchEvaluateDatapackReq,
            Field(description="Batch evaluation request containing multiple algorithm-datapack pairs"),
        ],
        _request_timeout: None
        | Annotated[StrictFloat, Field(gt=0)]
        | tuple[Annotated[StrictStr, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]] = None,
        _request_auth: dict[StrictStr, Any] | None = None,
        _content_type: StrictStr | None = None,
        _headers: dict[StrictStr, Any] | None = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[GenericResponseBatchEvaluateDatapackResp]:
        """List Datapack Evaluation Results

        Retrieve evaluation data for multiple algorithm-datapack pairs.

        :param request: Batch evaluation request containing multiple algorithm-datapack pairs (required)
        :type request: BatchEvaluateDatapackReq
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._evaluate_algorithm_on_datapacks_serialize(
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: dict[str, str | None] = {
            "200": "GenericResponseBatchEvaluateDatapackResp",
            "400": "GenericResponseAny",
            "401": "GenericResponseAny",
            "403": "GenericResponseAny",
            "500": "GenericResponseAny",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)

        assert response_data is not None and isinstance(response_data, RESTResponse), (
            "Response data must be of type RESTResponse"
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )  # type: ignore

    @validate_call
    def evaluate_algorithm_on_datapacks_without_preload_content(
        self,
        request: Annotated[
            BatchEvaluateDatapackReq,
            Field(description="Batch evaluation request containing multiple algorithm-datapack pairs"),
        ],
        _request_timeout: None
        | Annotated[StrictFloat, Field(gt=0)]
        | tuple[Annotated[StrictStr, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]] = None,
        _request_auth: dict[StrictStr, Any] | None = None,
        _content_type: StrictStr | None = None,
        _headers: dict[StrictStr, Any] | None = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """List Datapack Evaluation Results

        Retrieve evaluation data for multiple algorithm-datapack pairs.

        :param request: Batch evaluation request containing multiple algorithm-datapack pairs (required)
        :type request: BatchEvaluateDatapackReq
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._evaluate_algorithm_on_datapacks_serialize(
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: dict[str, str | None] = {
            "200": "GenericResponseBatchEvaluateDatapackResp",
            "400": "GenericResponseAny",
            "401": "GenericResponseAny",
            "403": "GenericResponseAny",
            "500": "GenericResponseAny",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)

        assert response_data is not None and isinstance(response_data, RESTResponse), (
            "Response data must be of type RESTResponse"
        )
        return response_data.response

    def _evaluate_algorithm_on_datapacks_serialize(
        self,
        request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:
        _host = None

        _collection_formats: dict[str, str] = {}

        _path_params: dict[str, str] = {}
        _query_params: list[tuple[str, str]] = []
        _header_params: dict[str, str | None] = _headers or {}
        _form_params: list[tuple[str, str]] = []
        _files: dict[str, str | bytes | list[str] | list[bytes] | list[tuple[str, bytes]]] = {}
        _body_params: bytes | None = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if request is not None:
            _body_params = request

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(["application/json"])

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params["Content-Type"] = _content_type
        else:
            _default_content_type = self.api_client.select_header_content_type(["application/json"])
            if _default_content_type is not None:
                _header_params["Content-Type"] = _default_content_type

        # authentication setting
        _auth_settings: list[str] = ["BearerAuth"]

        return self.api_client.param_serialize(
            method="POST",
            resource_path="/api/v2/evaluations/datapacks",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    def evaluate_algorithm_on_datasets(
        self,
        request: Annotated[
            BatchEvaluateDatasetReq,
            Field(description="Batch evaluation request containing multiple algorithm-dataset pairs"),
        ],
        _request_timeout: None
        | Annotated[StrictFloat, Field(gt=0)]
        | tuple[Annotated[StrictStr, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]] = None,
        _request_auth: dict[StrictStr, Any] | None = None,
        _content_type: StrictStr | None = None,
        _headers: dict[StrictStr, Any] | None = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> GenericResponseBatchEvaluateDatasetResp:
        """List Dataset Evaluation Results

        Retrieve evaluation data for multiple algorithm-dataset pairs.

        :param request: Batch evaluation request containing multiple algorithm-dataset pairs (required)
        :type request: BatchEvaluateDatasetReq
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._evaluate_algorithm_on_datasets_serialize(
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: dict[str, str | None] = {
            "200": "GenericResponseBatchEvaluateDatasetResp",
            "400": "GenericResponseAny",
            "401": "GenericResponseAny",
            "403": "GenericResponseAny",
            "500": "GenericResponseAny",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)

        assert response_data is not None and isinstance(response_data, RESTResponse), (
            "Response data must be of type RESTResponse"
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data  # type: ignore

    @validate_call
    def evaluate_algorithm_on_datasets_with_http_info(
        self,
        request: Annotated[
            BatchEvaluateDatasetReq,
            Field(description="Batch evaluation request containing multiple algorithm-dataset pairs"),
        ],
        _request_timeout: None
        | Annotated[StrictFloat, Field(gt=0)]
        | tuple[Annotated[StrictStr, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]] = None,
        _request_auth: dict[StrictStr, Any] | None = None,
        _content_type: StrictStr | None = None,
        _headers: dict[StrictStr, Any] | None = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[GenericResponseBatchEvaluateDatasetResp]:
        """List Dataset Evaluation Results

        Retrieve evaluation data for multiple algorithm-dataset pairs.

        :param request: Batch evaluation request containing multiple algorithm-dataset pairs (required)
        :type request: BatchEvaluateDatasetReq
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._evaluate_algorithm_on_datasets_serialize(
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: dict[str, str | None] = {
            "200": "GenericResponseBatchEvaluateDatasetResp",
            "400": "GenericResponseAny",
            "401": "GenericResponseAny",
            "403": "GenericResponseAny",
            "500": "GenericResponseAny",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)

        assert response_data is not None and isinstance(response_data, RESTResponse), (
            "Response data must be of type RESTResponse"
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )  # type: ignore

    @validate_call
    def evaluate_algorithm_on_datasets_without_preload_content(
        self,
        request: Annotated[
            BatchEvaluateDatasetReq,
            Field(description="Batch evaluation request containing multiple algorithm-dataset pairs"),
        ],
        _request_timeout: None
        | Annotated[StrictFloat, Field(gt=0)]
        | tuple[Annotated[StrictStr, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]] = None,
        _request_auth: dict[StrictStr, Any] | None = None,
        _content_type: StrictStr | None = None,
        _headers: dict[StrictStr, Any] | None = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """List Dataset Evaluation Results

        Retrieve evaluation data for multiple algorithm-dataset pairs.

        :param request: Batch evaluation request containing multiple algorithm-dataset pairs (required)
        :type request: BatchEvaluateDatasetReq
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._evaluate_algorithm_on_datasets_serialize(
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: dict[str, str | None] = {
            "200": "GenericResponseBatchEvaluateDatasetResp",
            "400": "GenericResponseAny",
            "401": "GenericResponseAny",
            "403": "GenericResponseAny",
            "500": "GenericResponseAny",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)

        assert response_data is not None and isinstance(response_data, RESTResponse), (
            "Response data must be of type RESTResponse"
        )
        return response_data.response

    def _evaluate_algorithm_on_datasets_serialize(
        self,
        request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:
        _host = None

        _collection_formats: dict[str, str] = {}

        _path_params: dict[str, str] = {}
        _query_params: list[tuple[str, str]] = []
        _header_params: dict[str, str | None] = _headers or {}
        _form_params: list[tuple[str, str]] = []
        _files: dict[str, str | bytes | list[str] | list[bytes] | list[tuple[str, bytes]]] = {}
        _body_params: bytes | None = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if request is not None:
            _body_params = request

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(["application/json"])

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params["Content-Type"] = _content_type
        else:
            _default_content_type = self.api_client.select_header_content_type(["application/json"])
            if _default_content_type is not None:
                _header_params["Content-Type"] = _default_content_type

        # authentication setting
        _auth_settings: list[str] = ["BearerAuth"]

        return self.api_client.param_serialize(
            method="POST",
            resource_path="/api/v2/evaluations/datasets",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )



"""
RCABench API

RCABench - A comprehensive root cause analysis benchmarking platform for microservices

The version of the OpenAPI document: 1.1.51
Contact: team@rcabench.com
Generated by OpenAPI Generator (https://rcabench.openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
from enum import Enum

from typing_extensions import Self


class ChaosChaosType(int, Enum):
    """
    ChaosChaosType
    """

    """
    allowed enum values
    """
    PodKill = 0
    PodFailure = 1
    ContainerKill = 2
    MemoryStress = 3
    CPUStress = 4
    HTTPRequestAbort = 5
    HTTPResponseAbort = 6
    HTTPRequestDelay = 7
    HTTPResponseDelay = 8
    HTTPResponseReplaceBody = 9
    HTTPResponsePatchBody = 10
    HTTPRequestReplacePath = 11
    HTTPRequestReplaceMethod = 12
    HTTPResponseReplaceCode = 13
    DNSError = 14
    DNSRandom = 15
    TimeSkew = 16
    NetworkDelay = 17
    NetworkLoss = 18
    NetworkDuplicate = 19
    NetworkCorrupt = 20
    NetworkBandwidth = 21
    NetworkPartition = 22
    JVMLatency = 23
    JVMReturn = 24
    JVMException = 25
    JVMGarbageCollector = 26
    JVMCPUStress = 27
    JVMMemoryStress = 28
    JVMMySQLLatency = 29
    JVMMySQLException = 30

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of ChaosChaosType from a JSON string"""
        return cls(json.loads(json_str))
